@@ -275,11 +275,11 @@ def _calculate_numeric_training_data(field_name: str, field_data: Series) -> Fie
         counts=counts.tolist(),
         min=np.min(finite_values),
         max=np.max(finite_values),
-        sum=np.sum(finite_values),
+        sum=np.sum(finite_values),  # type: ignore
         median=np.median(finite_values),
         average=np.average(finite_values),
-        std=np.std(finite_values),
-        variance=np.var(finite_values),
+        std=np.std(finite_values),  # type: ignore
+        variance=np.var(finite_values),  # type: ignore
         num_samples=len(finite_values),
         num_missing_values=np.count_nonzero(np.isnan(field_data)),
         num_posinf_values=np.count_nonzero(np.isposinf(field_data)),
